library(shiny)

# Load dataset
nhanes <- read.csv("nhanes.csv")
# Save certain variable ranges for plotting
nhanesXlim = range(nhanes$LENGTH_CM)
nhanesYlim = range(nhanes$WEIGHT_KG)

# Define server logic required to draw a histogram
shinyServer(function(input, output) {
  
  # Expression that generates a scatterplot. The expression is
  # wrapped in a call to renderPlot to indicate that:
  #
  #  1) It is "reactive" and therefore should re-execute automatically
  #     when inputs change
  #  2) Its output type is a plot
  
  output$scatterplot <- renderPlot({
    # Draw the scatterplot for the specified data subset
    with(subset(nhanes, MONTHS == input$age & GENDER == input$gender),
         plot(LENGTH_CM, WEIGHT_KG,
              xlim = nhanesXlim, ylim = nhanesYlim,
              xlab = "Length (cm)", ylab = "Weight (kg)",
              main = paste("NHANES data for", input$gender, "babies",
                           input$age, "months old"))
    )
  })
})